# #
# # Copyright (c) 2021, NVIDIA CORPORATION.
# #
# # Licensed under the Apache License, Version 2.0 (the "License");
# # you may not use this file except in compliance with the License.
# # You may obtain a copy of the License at
# #
# #     http://www.apache.org/licenses/LICENSE-2.0
# #
# # Unless required by applicable law or agreed to in writing, software
# # distributed under the License is distributed on an "AS IS" BASIS,
# # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# # See the License for the specific language governing permissions and
# # limitations under the License.
# #
#
import pytest

import merlin.models.tf as mm
from merlin.models.tf.utils import testing_utils


@pytest.mark.parametrize("run_eagerly", [True, False])
@pytest.mark.parametrize(
    "prediction_blocks", [None, mm.BinaryOutput("click"), mm.BinaryClassificationTask("click")]
)
def test_ncf_model(ecommerce_data, run_eagerly, prediction_blocks):
    ecommerce_data.schema = ecommerce_data.schema.select_by_name(["user_id", "item_id", "click"])
    model = mm.benchmark.NCFModel(
        ecommerce_data.schema,
        embedding_dim=2,
        mlp_block=mm.MLPBlock([2]),
        prediction_tasks=prediction_blocks,
    )

    testing_utils.model_test(model, ecommerce_data, run_eagerly=run_eagerly)
